@@ -357,7 +357,7 @@ class CreateDomainBatchRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param TemplateId: 模板ID
+        :param TemplateId: 模板ID。详情请查看：[获取模板列表](https://cloud.tencent.com/document/product/242/48940)
         :type TemplateId: str
         :param Period: 购买域名的年限，可选值：[1-10]
         :type Period: int
@@ -365,11 +365,16 @@ class CreateDomainBatchRequest(AbstractModel):
         :type Domains: list of str
         :param PayMode: 付费模式 0手动在线付费，1使用余额付费
         :type PayMode: int
+        :param AutoRenewFlag: 自动续费开关。有两个可选值：
+0 表示关闭，不自动续费（默认值）
+1 表示开启，将自动续费
+        :type AutoRenewFlag: int
         """
         self.TemplateId = None
         self.Period = None
         self.Domains = None
         self.PayMode = None
+        self.AutoRenewFlag = None
 
 
     def _deserialize(self, params):
@@ -377,6 +382,7 @@ class CreateDomainBatchRequest(AbstractModel):
         self.Period = params.get("Period")
         self.Domains = params.get("Domains")
         self.PayMode = params.get("PayMode")
+        self.AutoRenewFlag = params.get("AutoRenewFlag")
 
 
 class CreateDomainBatchResponse(AbstractModel):
@@ -793,6 +799,46 @@ class DescribeTemplateListResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeTemplateRequest(AbstractModel):
+    """DescribeTemplate请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TemplateId: 模板ID
+        :type TemplateId: str
+        """
+        self.TemplateId = None
+
+
+    def _deserialize(self, params):
+        self.TemplateId = params.get("TemplateId")
+
+
+class DescribeTemplateResponse(AbstractModel):
+    """DescribeTemplate返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Template: 模板信息
+        :type Template: :class:`tencentcloud.domain.v20180808.models.TemplateInfo`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Template = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Template") is not None:
+            self.Template = TemplateInfo()
+            self.Template._deserialize(params.get("Template"))
+        self.RequestId = params.get("RequestId")
+
+
 class DomainBaseInfo(AbstractModel):
     """获取域名基础信息
 
@@ -856,10 +902,14 @@ TransferPending：待转入中
 TransferTransing：转入中
 TransferFailed：转入失败
         :type BuyStatus: str
-        :param RegistrarType: 注册类型
-epp （腾讯云自有域名）
-xinnet (新网域名)
+        :param RegistrarType: 注册商类型
+epp: DNSPod, Inc.（烟台帝思普网络科技有限公司）
+qcloud: Tencent Cloud Computing (Beijing) Limited Liability Company（腾讯云计算（北京）有限责任公司）
+yunxun: Guangzhou Yunxun Information Technology Co., Ltd.（广州云讯信息科技有限公司）
+xinnet: Xin Net Technology Corporation（北京新网数码信息技术有限公司）
         :type RegistrarType: str
+        :param NameServer: 域名绑定的ns
+        :type NameServer: list of str
         """
         self.DomainId = None
         self.DomainName = None
@@ -872,6 +922,7 @@ xinnet (新网域名)
         self.DomainStatus = None
         self.BuyStatus = None
         self.RegistrarType = None
+        self.NameServer = None
 
 
     def _deserialize(self, params):
@@ -886,6 +937,7 @@ xinnet (新网域名)
         self.DomainStatus = params.get("DomainStatus")
         self.BuyStatus = params.get("BuyStatus")
         self.RegistrarType = params.get("RegistrarType")
+        self.NameServer = params.get("NameServer")
 
 
 class DomainBatchDetailSet(AbstractModel):
@@ -1155,16 +1207,23 @@ class RenewDomainBatchRequest(AbstractModel):
         :type Domains: list of str
         :param PayMode: 付费模式 0手动在线付费，1使用余额付费。
         :type PayMode: int
+        :param AutoRenewFlag: 自动续费开关。有三个可选值：
+0 表示关闭，不自动续费
+1 表示开启，将自动续费
+2 表示不处理，保留域名原有状态（默认值）
+        :type AutoRenewFlag: int
         """
         self.Period = None
         self.Domains = None
         self.PayMode = None
+        self.AutoRenewFlag = None
 
 
     def _deserialize(self, params):
         self.Period = params.get("Period")
         self.Domains = params.get("Domains")
         self.PayMode = params.get("PayMode")
+        self.AutoRenewFlag = params.get("AutoRenewFlag")
 
 
 class RenewDomainBatchResponse(AbstractModel):
@@ -1238,7 +1297,7 @@ class TemplateInfo(AbstractModel):
         """
         :param TemplateId: 模板ID
         :type TemplateId: str
-        :param AuditStatus: 认证状态
+        :param AuditStatus: 认证状态：未实名认证:NotUpload, 实名审核中:InAudit，已实名认证:Approved，实名审核失败:Reject
         :type AuditStatus: str
         :param CreatedOn: 创建时间
         :type CreatedOn: str
@@ -1246,7 +1305,7 @@ class TemplateInfo(AbstractModel):
         :type UpdatedOn: str
         :param UserUin: 用户UIN
         :type UserUin: str
-        :param IsDefault: 是否是默认模板
+        :param IsDefault: 是否是默认模板: 是:yes，否:no
         :type IsDefault: str
         :param AuditReason: 认证失败原因
         :type AuditReason: str
@@ -1305,11 +1364,16 @@ class TransferInDomainBatchRequest(AbstractModel):
         :type TemplateId: str
         :param PayMode: 付费模式 0手动在线付费，1使用余额付费。
         :type PayMode: int
+        :param AutoRenewFlag: 自动续费开关。有两个可选值：
+0 表示关闭，不自动续费（默认值）
+1 表示开启，将自动续费
+        :type AutoRenewFlag: int
         """
         self.Domains = None
         self.PassWords = None
         self.TemplateId = None
         self.PayMode = None
+        self.AutoRenewFlag = None
 
 
     def _deserialize(self, params):
@@ -1317,6 +1381,7 @@ class TransferInDomainBatchRequest(AbstractModel):
         self.PassWords = params.get("PassWords")
         self.TemplateId = params.get("TemplateId")
         self.PayMode = params.get("PayMode")
+        self.AutoRenewFlag = params.get("AutoRenewFlag")
 
 
 class TransferInDomainBatchResponse(AbstractModel):
